<?php

if ($user->isAuth()) {
    redirect('/');
    exit;
}

$form = [
    'value' => [
        'email' => isset($_POST['email']) ? mb_strtolower(trim($_POST['email'])) : null,
        'password' => isset($_POST['password']) ? trim($_POST['password']) : null,
    ],
    'error' => [],
];

if (isset($_POST['submit'])) {
    $stmt = $db->prepare("SELECT user_id, email, password FROM users WHERE email = :email");
    $stmt->bindParam(':email', $form['value']['email'], PDO::PARAM_STR);
    $stmt->execute();

    $result = $stmt->fetch(PDO::FETCH_OBJ);

    if (empty($form['value']['email'])) {
        $form['error']['email'] = 'Необходимо ввести имейл';
    } elseif (!filter_var($form['value']['email'], FILTER_VALIDATE_EMAIL)) {
        $form['error']['email'] = 'Введите корректный имейл';
    } elseif (@$result->email !== $form['value']['email']) {
        $form['error']['email'] = 'Пользователь с таким имейлом не найден';
    }

    if (empty($form['value']['password'])) {
        $form['error']['password'] = 'Необходимо ввести пароль';
    } elseif (@count($form['error']['email']) == 0) {
        if (!password_verify($form['value']['password'], $result->password)) {
            $form['error']['password'] = 'Пароль неверный';
        }
    }

    if (count($form['error']) == 0) {
        $user_id = $result->user_id;
        $token = md5(random_string());

        $created_at = date('Y-m-d H:i:s', time());

        $stmt = $db->prepare("INSERT INTO users_sessions SET user_id = :user_id, token = :token, created_at = :created_at");
        $stmt->bindParam(':user_id', $user_id, PDO::PARAM_INT);
        $stmt->bindParam(':token', $token, PDO::PARAM_STR);
        $stmt->bindParam(':created_at', $created_at, PDO::PARAM_STR);
        $stmt->execute();

        $session = json_encode([
            'user_id' => base64_encode($user_id),
            'token' => base64_encode($token),
        ]);

        $session = base64_encode($session);

        setcookie('__session', $session, 86400 * 365 + time(), '/');

        $_SESSION['__session'] = $session;

        redirect('/');
        exit;
    }
}

echo $template->render('user.login', [
    'form' => $form,
]);
